# Changelog

## 0.1.0 - 2023-12-21

This major release is a prototype intended for project fine-tuning and provider developments.

### features

- host os: nt, posix
- target os: nt, posix, android
- framework: bmy, mfs, msh, mlib, mpython
- tools: mtools, myrrhc

### tested features

- host os: nt, posix
- target os: nt, posix
- framework: bmy(partial), mfs, msh, mlib, mpython(partial)
- tools: myrrhc(partial)

